@@ -26,8 +26,9 @@
 
 #include "unistr.h"
 #include "unictype.h"
-#include "uniwbrk.h"
 #include "uninorm.h"
+#include "caseprop.h"
+#include "context.h"
 #include "special-casing.h"
 
 #define FUNC u16_casemap
