@@ -30,7 +30,9 @@ u16_tolower (const uint16_t *s, size_t n, const char *iso639_language,
 	     uninorm_t nf,
 	     uint16_t *resultbuf, size_t *lengthp)
 {
-  return u16_casemap (s, n, iso639_language,
+  return u16_casemap (s, n,
+		      unicase_empty_prefix_context, unicase_empty_suffix_context,
+		      iso639_language,
 		      uc_tolower, offsetof (struct special_casing_rule, lower[0]),
 		      nf,
 		      resultbuf, lengthp);
